import React, { ReactNode } from 'react';
import { IButtonProps } from '../elements/button/types';
export interface ISlideoverProps extends React.ComponentPropsWithoutRef<'div'> {
    /**
     * Defines the focus delay to focus container
     * to trigger Escape event
     */
    focusDelay?: number;
    /**
     * Defines the slideover order on the DOM based on the z-{index} class
     */
    zIndex?: string;
    /**
     * Defines the top spacing of the slide-over
     */
    top?: string;
    /**
     * Defines the boxShadow of the slide-over
     */
    boxShadow?: string;
    /**
     * Defines the max width of the slide-over, e.g. max-w-md, max-w-2xl, max-w-3xl
     */
    wider?: string;
    /**
     * Defines the outside close icon
     */
    outSideClose?: boolean;
    /**
     * Defines the outside icon
     */
    iconProps?: IButtonProps;
    /**
     * Defines the slide over open
     */
    isOpen: boolean;
    /**
     * Defines the call back on close
     */
    onClose: () => void;
    /**
     * Defines the call back when "Escape"
     */
    onDismiss?: (event: React.SyntheticEvent | Event) => void;
    /**
     * Defines overlay opacity, e.g. opacity-50
     */
    overlayOpacity?: string;
    /**
     * Defines if overlay title is visible or not
     */
    showOverlayTitle?: boolean;
    /**
     * Defines the level/layer of this slideover
     */
    level?: number;
    /**
     * Defines the total number of slideovers are opened
     */
    totalLayers?: number;
}
declare const Slideover: ({ focusDelay, className, zIndex, top, boxShadow, wider, outSideClose, iconProps, isOpen, onClose, onDismiss, onKeyDown, children, overlayOpacity, showOverlayTitle, level, totalLayers, ...other }: ISlideoverProps) => JSX.Element;
export default Slideover;
export interface IBrandColorProps {
    /**
     * Defines header appearance
     */
    header: string;
    /**
     * Defines the description appearance
     */
    description: string;
    /**
     * Defines the title appearance
     */
    title: string;
}
export interface IHeaderProps extends Omit<React.ComponentPropsWithoutRef<'header'>, 'title'> {
    /**
     * Defines the header background color, title & header
     */
    brandColors?: IBrandColorProps;
    /**
     * Defines the description area in the header
     */
    description?: ReactNode;
    /**
     * Hides header shadow
     */
    hideShadow?: boolean;
    /**
     * Defines the close icon
     */
    iconProps?: IButtonProps;
    /**
     * Defines the close icon to show
     */
    showCloseIcon?: boolean;
    /**
     * Defines the header title
     */
    title: ReactNode;
    /**
     * Defines close action
     */
    onClose: () => void;
}
export declare function SlideoverHeader({ brandColors, className, description, hideShadow, iconProps, showCloseIcon, title, onClose, ...other }: IHeaderProps): JSX.Element;
interface ISlideoverFooterProps extends React.ComponentPropsWithoutRef<'footer'> {
    /**
     * Defines the rendering children as render props
     */
    children: ReactNode;
}
export declare function SlideoverFooter({ className, children, ...other }: ISlideoverFooterProps): JSX.Element;
export declare function SlideoverContent({ className, children, ...other }: any): JSX.Element;
//# sourceMappingURL=Slideover.d.ts.map